exceptiontools.ContextContainmentError
======================================

.. inheritance-diagram:: abjad.tools.exceptiontools.ContextContainmentError.ContextContainmentError
   :private-bases:

.. autoclass:: abjad.tools.exceptiontools.ContextContainmentError.ContextContainmentError

Special Methods
---------------

.. automethod:: abjad.tools.exceptiontools.ContextContainmentError.ContextContainmentError.__delattr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.ContextContainmentError.ContextContainmentError.__getitem__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.ContextContainmentError.ContextContainmentError.__getslice__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.ContextContainmentError.ContextContainmentError.__repr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.ContextContainmentError.ContextContainmentError.__setattr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.ContextContainmentError.ContextContainmentError.__setstate__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.ContextContainmentError.ContextContainmentError.__str__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.ContextContainmentError.ContextContainmentError.__unicode__

    Inherited from :py:class:`exceptions.BaseException`
